
/*
Data from Lochinkohl & Boehm. HortScience 36: 790-794.
This is only part of a bigger data set. 

Treatment design: factorial (2-way)
Experimental design: split-plot with blocks

block:	block -RANDOM (arbitrary 5, 6, 7 numbering) -- random
gen:	turf genotype - FIXED EFFECT (WHOLE-plot factor:1, 2, or 3)
comp:	compost treatment - FIXED EFFECT (yes (1) or no (0)) (SUB-plot factor)
code:	not used here
trt:	coding for combination of COMP and GEN (a "treatment " coding, not used).
yy:		response (dependent) variable. 
		% turfgrass cover of seeded plot (depends on disease).

yy is transformed to y=arcsin(sqrt(yy/100)) for variance stabilization.

Note: the whole-plot random effect corresponds to BLOCK*GEN.
One thus needs random effects of BLOCK and BLOCK*GEN in the model.
*/

title 'Split plot, with blocks (turf data from Lochinkohl & Boehm)';
data split;
 input block gen comp code trt yy;
 y=arsin(sqrt(yy/100)); *<--y is transformed yy (stabilize variances);
 comp=comp+1; *<---get compost code into 1-2 format (instead of 0-1);
datalines;
5	3	1	2	31	80
5	3	0	2	30	60
5	1	1	2	11	85
5	1	0	2	10	70
5	2	0	2	20	75
5	2	1	2	21	85
6	3	1	2	31	75
6	3	0	2	30	55
6	2	1	2	21	90
6	2	0	2	20	60
6	1	1	2	11	70
6	1	0	2	10	45
7	3	0	2	30	75
7	3	1	2	31	85
7	2	1	2	21	80
7	2	0	2	20	80
7	1	0	2	10	60
7	1	1	2	11	80
;
run;

**************************************************************************************;
************************ Analyze as a split plot, with blocks ************************;
*********************** Fixed effects are GEN COMP and GEN*COMP **********************;
**************************************************************************************;

/* You need a RANDOM BLOCK BLOCK*GEN; statement */

*ods html ;
*ods graphics on;
proc glimmix data=split plots=studentpanel;
title2 'Mixed-model analysis (random block and block*gen)';
class block gen comp;
model y = gen|comp/ ddfm=KR;		*<--if unbalanced, good to use KR df option;
random block block*gen;				*<--random block and block*gen (the whole-plot error);
lsmeans comp / diff lines plot=mean(join cl ) ;
*---With no interaction, no slices needed (one shown here as a demo)...;
lsmeans gen*comp / slice=gen plot=(mean(join cl sliceby=comp)  diff) ;
run;
*ods graphics off;
*ods html close;
run;

*^--Note: Histogram of (studentized) residuals is most useful with MANY observations,
	more than in this data set. Other plots are ALWAYS useful (for any number of 
	observations).;
run;

