
/*
Study on the effects of Previous Crop (PC), wheat variety (VAR), and fungicide treatment (TRT)
on severity of Fusarium Head Blight (FHB_SEV) and DON toxin in harvest wheat grain.

Treatment Design: 		Three-way factorial (factors crossed)
Experimental Design: 	Consider this a Split-Split-Plot, plus Blocks.

REP:	Block
PC		Previous Crop (whole-plot) (first factor)
VAR		Variety (A-E, relabeled for visual purposes) (sub-plot) (second factor)
TRT		Fungicide treatment at GS 10.5.1 (1-control, 2-treated) (sub-sub-plot)
		(the third factor). 
FHB_SEV	% of spike area with symptoms (a response variable)
DON		Toxin in grain (a response variable)

Disease severity transformed to angular values and to logits (used here).
DON transforrmed to SDON = sqrt(DON).

Note: One of the factors is called fungicide "Treatment", but one could also refer
to the entire "Treatment Design" for all the factors, as described above.

Experiment part of an Integrated Disease Management investigation involving multiple 
states and years. Particular data set from L. Sweets. 
See Willyerd et al. 2012 (Plant Disease 96:957-967) for a desription of the overall investigation.
*/


title 'Split-split-plot (plus blocks) for FHB and DON management';
data sw;
input REP	PC $	VAR1 $	TRT	FHB_SEV	DON;
sdon=sqrt(don);
angular = arsin(sqrt(FHB_SEV/100));
logit=log(fhb_sev/(100-fhb_sev));
var = var1; if (var1 eq 'A') then var = 'D'; if (var1 eq 'B') then var = 'A';
if (var1 eq 'C') then var = 'B'; if (var1 eq 'D') then var = 'C';
*^variety labels (arbitrary) re-coded to see better in graphs;
datalines;
1	Corn	A	1	15.00	4.10
1	Corn	A	2	12.50	2.30
1	Corn	B	1	55.00	19.70
1	Corn	B	2	55.00	14.50
1	Corn	C	1	35.00	15.90
1	Corn	C	2	30.00	6.80
1	Corn	D	1	30.00	7.10
1	Corn	D	2	35.00	6.50
1	Corn	E	1	20.00	3.50
1	Corn	E	2	20.00	4.80
1	SOYBEAN	A	1	12.00	1.40
1	SOYBEAN	A	2	15.00	0.80
1	SOYBEAN	B	1	60.00	7.10
1	SOYBEAN	B	2	40.00	4.10
1	SOYBEAN	C	1	30.00	3.30
1	SOYBEAN	C	2	25.00	2.30
1	SOYBEAN	D	1	15.00	1.70
1	SOYBEAN	D	2	10.00	1.10
1	SOYBEAN	E	1	20.00	2.00
1	SOYBEAN	E	2	18.50	1.20
2	Corn	A	1	20.00	4.60
2	Corn	A	2	18.00	4.70
2	Corn	B	1	75.00	24.60
2	Corn	B	2	85.00	16.60
2	Corn	C	1	40.00	11.50
2	Corn	C	2	45.00	12.90
2	Corn	D	1	40.00	8.30
2	Corn	D	2	22.50	4.10
2	Corn	E	1	25.00	7.00
2	Corn	E	2	30.00	6.00
2	SOYBEAN	A	1	15.00	0.90
2	SOYBEAN	A	2	10.00	0.50
2	SOYBEAN	B	1	70.00	6.20
2	SOYBEAN	B	2	45.00	3.80
2	SOYBEAN	C	1	25.00	3.00
2	SOYBEAN	C	2	24.50	1.40
2	SOYBEAN	D	1	12.50	2.10
2	SOYBEAN	D	2	15.00	1.10
2	SOYBEAN	E	1	10.00	1.00
2	SOYBEAN	E	2	12.50	0.60
3	Corn	A	1	24.50	4.70
3	Corn	A	2	20.00	3.10
3	Corn	B	1	60.00	22.60
3	Corn	B	2	50.00	13.10
3	Corn	C	1	55.00	14.80
3	Corn	C	2	35.00	5.90
3	Corn	D	1	45.00	10.10
3	Corn	D	2	35.00	5.40
3	Corn	E	1	15.00	7.90
3	Corn	E	2	15.00	4.30
3	SOYBEAN	A	1	20.00	1.10
3	SOYBEAN	A	2	5.00	0.50
3	SOYBEAN	B	1	55.00	3.90
3	SOYBEAN	B	2	25.00	2.10
3	SOYBEAN	C	1	40.00	2.10
3	SOYBEAN	C	2	15.00	1.20
3	SOYBEAN	D	1	10.00	1.70
3	SOYBEAN	D	2	12.50	0.90
3	SOYBEAN	E	1	12.50	0.70
3	SOYBEAN	E	2	15.00	0.60
4	Corn	A	1	12.50	5.40
4	Corn	A	2	28.50	7.80
4	Corn	B	1	50.00	18.40
4	Corn	B	2	40.00	13.30
4	Corn	C	1	30.00	12.40
4	Corn	C	2	40.00	11.00
4	Corn	D	1	47.50	7.60
4	Corn	D	2	25.00	4.70
4	Corn	E	1	25.00	4.60
4	Corn	E	2	10.00	3.30
4	SOYBEAN	A	1	15.00	0.70
4	SOYBEAN	A	2	7.50	0.70
4	SOYBEAN	B	1	50.00	3.50
4	SOYBEAN	B	2	42.50	2.10
4	SOYBEAN	C	1	25.00	1.90
4	SOYBEAN	C	2	25.00	1.30
4	SOYBEAN	D	1	12.50	1.70
4	SOYBEAN	D	2	15.00	1.20
4	SOYBEAN	E	1	10.00	0.60
4	SOYBEAN	E	2	20.00	0.70
5	Corn	A	1	25.00	4.80
5	Corn	A	2	18.50	2.20
5	Corn	B	1	65.00	14.30
5	Corn	B	2	55.00	10.70
5	Corn	C	1	45.00	9.80
5	Corn	C	2	35.00	7.60
5	Corn	D	1	32.50	7.60
5	Corn	D	2	20.00	5.20
5	Corn	E	1	25.00	3.70
5	Corn	E	2	12.50	2.00
5	SOYBEAN	A	1	10.00	1.00
5	SOYBEAN	A	2	12.50	0.60
5	SOYBEAN	B	1	60.00	5.00
5	SOYBEAN	B	2	35.00	2.00
5	SOYBEAN	C	1	28.50	2.30
5	SOYBEAN	C	2	15.00	1.00
5	SOYBEAN	D	1	15.00	1.90
5	SOYBEAN	D	2	12.50	0.90
5	SOYBEAN	E	1	20.00	1.10
5	SOYBEAN	E	2	10.00	0.10
6	Corn	A	1	20.00	3.00
6	Corn	A	2	12.50	2.10
6	Corn	B	1	40.00	12.70
6	Corn	B	2	35.00	6.40
6	Corn	C	1	40.00	8.00
6	Corn	C	2	25.00	6.40
6	Corn	D	1	40.00	5.70
6	Corn	D	2	15.00	3.10
6	Corn	E	1	35.00	3.30
6	Corn	E	2	15.00	3.10
6	SOYBEAN	A	1	5.00	0.80
6	SOYBEAN	A	2	15.00	0.60
6	SOYBEAN	B	1	50.00	3.00
6	SOYBEAN	B	2	30.00	3.80
6	SOYBEAN	C	1	12.50	2.40
6	SOYBEAN	C	2	12.50	1.60
6	SOYBEAN	D	1	20.00	2.20
6	SOYBEAN	D	2	10.00	0.90
6	SOYBEAN	E	1	15.00	0.80
6	SOYBEAN	E	2	15.00	0.50
;
run;
*proc print data=sw;run;
*ods html style=statistical;



*---Initial analysis;
*ods html;
*ods graphics on;
proc glimmix data=sw plots=studentpanel;
title2 'Analysis of disease SEVERITY (untransformed) ';
class rep PC VAR TRT;
model FHB_SEV = PC|VAR|TRT / ddfm=kr;	*<--because of balance, KR is not needed (doesn't hurt);
random rep rep*PC VAR(rep PC) ;	*<--random effects for split-split plot plus blocks;
run;
*ods graphics off;
*ods html close;
run;

*---Use transformation of response variable for disease. Angular also is good;
*ods html;
*ods graphics on;
proc glimmix data=sw plots=studentpanel;
title2 'Analysis of logit of FHB disease severity';
class rep PC VAR TRT;
model logit = PC|VAR|TRT / ddfm=kr;
random rep rep*PC VAR(rep PC) ;	*<--random effects for split-split plot plus blocks;
run;
*ods graphics off;
*ods html close;
run;

/*
*---Hypothetical diversion...;
*---What if this is a Split-Plot (with blocks), with two whole plots (PC _and_ VAR), and
	TRT for the sub-splot (no sub-sub plot)? Then, the model would be;
proc glimmix data=sw plots=studentpanel;
title2 'Analysis of logit of FHB disease severity, hypothetical different exper. layout';
class rep PC VAR TRT;
model logit = PC|VAR|TRT / ddfm=kr;
random rep rep*PC*VAR  ;	*<--random effects for split-plot plus blocks;
run;
*---What if this is a split plot, with PC as whole plot, but with VAR _and_ TRT as
	sub-plots (no sub-sub-plot)?;
proc glimmix data=sw plots=studentpanel;
title2 'Analysis of logit of FHB disease severity, hypothetical different exper. layout';
class rep PC VAR TRT;
model logit = PC|VAR|TRT / ddfm=kr;
random rep rep*PC  ;	*<--random effects for split-plot plus blocks;
run;
*/


*---Look (inelegantly) at all pair-wise mean differences (with a 3-way interaction);
*ods html;
*ods graphics on;
proc glimmix data=sw  ;
title2 'Analysis of logit of FHB disease severity';
class rep PC VAR TRT;
model logit = PC|VAR|TRT / ddfm=kr;
random rep rep*PC VAR(rep PC) ;	
lsmeans pc*var*trt/ diff lines  ;	*<---all pairs of interaction means;
run;
*ods graphics off;
*ods html close;
run;

*---Note: with a 3-way interaction, one or more 2-way interactions vary with the level
	of the _other_ factor. For instance here, the only sig. 2-way interaction is
	PC*VAR. Because there is a 3-way interaction, this means (in part) that PC*VAR
	is different (somehow) for TRT=1 and TRT=2. Explore below. ;
*ods html;
*ods graphics on;
proc glimmix data=sw ;
title2 'Analysis of logits of severity, slices for exploring interactions';
class rep PC VAR TRT;
model logit = PC|VAR|TRT / ddfm=KR;
random rep rep*PC VAR(rep PC) ;
*---Divide up the 3-way interaction into portions (sliceby= and plotby=).
	Separate graphs for each plotby=. Separate lines for each sliceby=.
	Can also get Slices of LS Means. Start by looking at TRT effect on the
	VAR*PC interaction.;
lsmeans pc*var*trt / slice=trt  plots=mean(sliceby=pc join cl plotby=trt);
run;
*ods graphics off;
*ods html close;
run;


*ods html;
*ods graphics on;
proc glimmix data=sw ;
title2 'Analysis of logits of severity, slices for exploring interactions';
class rep PC VAR TRT;
model logit = PC|VAR|TRT ;
random rep rep*PC VAR(rep PC) ;
*---Since VAR*PC is significant for both treatments (see above slices), one
	must tease apart this two-way interaction in more detail (for each TRT level). 
	Here, with a slice at var*trt (instead of at trt), we see how the 
	effect of the third factor (PC) varies with the other levels (VAR*TRT);
	*lsmeans pc*var*trt / slice=trt plots=mean(sliceby=pc join cl plotby=trt);
lsmeans pc*var*trt / slice=(trt var*trt) plots=mean(sliceby=pc join cl plotby=trt);
*---Use SLICE statement to get mean separations.;
slice pc*var*trt / sliceby=var*trt lines;
run;
*ods graphics off;
*ods html close;
run;


*ods html;
*ods graphics on;
proc glimmix data=sw ;
title2 'Analysis of logits of severity, slices for exploring interactions';
class rep PC VAR TRT;
model logit = PC|VAR|TRT;
random rep rep*PC VAR(rep PC) ;
lsmeans pc*var*trt / slice=trt plots=mean(sliceby=pc join cl plotby=trt);
*---With the three-way interaction, one can turn this around and say that TRT
	effect depends on level of PC*VAR. Explore this with different graphs and slices.;
lsmeans pc*var*trt / slice=PC*VAR plots=mean(sliceby=trt join cl plotby=pc);
slice pc*var*trt / sliceby=PC*VAR lines;
run;
*ods graphics off;
*ods html close;
run;


*---When there is a 3-way interaction, one cannot directly interpret a 2-way interaction.
	In particular, the 2-way interactions for each level of the third factor could
	cancel out, or they could be maintained. One must look at the data. Here,
	we see if there is a sig. PC*TRT interaction at each level of VAR (that is then
	cancelled out with the overall 2-way).;
*ods html;
*ods graphics on;
proc glimmix data=sw ;
title2 'Analysis of logits of severity, slices for exploring interactions';
class rep PC VAR TRT;
model logit = PC|VAR|TRT;
random rep rep*PC VAR(rep PC) ;
lsmeans pc*trt / lines plots=mean(sliceby=trt join cl);	
*^--pretend that there is a 2-way inter., but no 3-way inter.;
lsmeans pc*var*trt /  slice=var plots=mean(sliceby=trt join cl plotby=var);
run;
*ods graphics off;
*ods html close;
run;

*---Key point above, a 2-way interaction result _can_ be very misleading when there is
	a true 3-way interaction.;
*---We repeat above, put include a SLICE statement to look at the PC*TRT interaction
	at each level of VAR (getting LINES display);
*ods html;
*ods graphics on;
proc glimmix data=sw ;
title2 'Analysis of logits of severity, slices for exploring interactions';
class rep PC VAR TRT;
model logit = PC|VAR|TRT;
random rep rep*PC VAR(rep PC) ;
lsmeans pc*trt / lines plots=mean(sliceby=trt join cl);
lsmeans pc*var*trt /  slice=var plots=mean(sliceby=trt join cl plotby=var);
slice pc*var*trt / sliceby=var lines;
run;
*ods graphics off;
*ods html close;
run;


*ods html;
*ods graphics on;
proc glimmix data=sw ;
title2 'Analysis of logits of severity, slices for exploring interactions';
class rep PC VAR TRT;
model logit = PC|VAR|TRT;
random rep rep*PC VAR(rep PC) ;
*---With 3-way interactions, direction of the slicing is somewhat arbitrary.
	Here we emphasize the VAR effects.;
lsmeans pc*var*trt /  plots=mean(sliceby=VAR join cl plotby=trt);
slice pc*var*trt / sliceby=PC*TRT lines;
run;
*ods graphics off;
*ods html close;
run;

*---In most of the above analyses, we looked at the 3-way interaction means from
	different angles (different slices and graphs). But, because of this interaction,
	we always used the mu_ijk means. Which angle to take for presentation (of the mu_ijk)
	will depend on the objectives of the investigator.;

/*
*---FOR LATER....;
*---Note: with a 3-way interaction, one or more 2-way interactions vary with the level
	of the _other_ factor. For instance here, the only sig. 2-way interaction is
	PC*VAR. Because there is a 3-way interaction, this means (in part) that PC*VAR
	is different (somehow) for TRT=1 and TRT=2. Explore below. ;
*ods html;
*ods graphics on;
proc glimmix data=sw ;
title2 'Analysis of logits of severity, slices for exploring interactions';
class rep PC VAR TRT;
model logit = PC|VAR|TRT / ddfm=KR;
random rep rep*PC VAR(rep PC) ;
*---Divide up the 3-way interaction into portions (sliceby= and plotby=).
	Separate graphs for each plotby=. Separate lines for each sliceby=.
	Can also get Slices of LS Means. Start by looking at TRT effect on the
	VAR*PC interaction.;
lsmeans pc*var*trt / slice=trt  plots=mean(sliceby=pc join cl plotby=trt);

*---For variety A, does previous crop affect means for trt 1 (one) and trt 2 (two), 
	and does the PC effect change with TRT? Do nonpositional (easy) and positional
	syntax (harder).;
lsmestimate pc*var*trt 'one' [1,1 1 1] [-1,2 1 1], 
		'two' [1,1 1 2] [-1,2 1 2],
		'diff' [1,1 1 1] [-1,2 1 1] [-1,1 1 2] [1,2 1 2];
lsmestimate pc*var*trt 'one posi' 1 0 0 0 0 0 0 0 0 0 -1, 
		'two posi' 0 1 0 0 0 0 0 0 0 0 0 -1,
		'diff posi' 1 -1 0 0 0 0 0 0 0 0 -1 1;
run;
*ods graphics off;
*ods html close;
run;
*/


****************************************************************************************;
***************************** Now look at DON as the response **************************;
****************************************************************************************;

*----->>> Try this on your own ------>>>>>:
