
/*
Effects of Temperature and Wetness Duration on incidence of strawberry leaflets with
Phomposis leaf blight. 
Data from Nita, Ellis, and Madden. 2003. Plant Dis. 87: 579-584.

incidence	proportion of leaflets with symptoms of Phomopsis of strawberry (disease)
T			temperature (whole-plot)
W			wetness duration (sub-plot)
R			repetition of experiment (a blocking factor) - random

logit		logit transformation of diseasse
angular		arcsin(sqrt(incidence))
cll			CLL transformation of disease [ln(-log(1-incidence))]

Treatment structure: Two fixed-effect factors (crossed) -- factorial
Experimental structure: split-plot with blocks (repititions of the experiment)

Growth-chamber study: chamber was set a T, and then plants were exposed to different durations
of wetness. Plants were randomly selected and removed after 5, 10, ..., hours of Wetness. Chamber
was randomly re-set to a different T for each run. Thus, T is the whole-plot, and W
is the sub-plot (randomized within each level of T). One could consider W as a Repeated
Measure, and this was done by Nita et al. But here we take a simpler approach, and
just treat W as a sub-plot (which is a special case of a repeated measure). The fact
that each plant was only observed for one wetness duration justifies this approach

Note: this is a condensed form of the full data set. The original data set had separate 
observations for young, medium, and old leaves, based on spatial position. Thus, Age was
a spatially repeated measure (greatly complicating the analysis -- not for here). For
this demonstration exercise only, we calculated disease per plant across the three Ages, 
so that there is one response variable per experimental unit. Age actually has a big effect,
and this omission can affect other hypothesis tests. For our purposes now, we assume that
we did not keep track of age, and just have a mean disease value for each unit.
*/


data tw2;
input R T W incidence logit angular cll;
Wc=W; *<--make a duplicate variable for wetness, for later use;
sW = sqrt(W); lW=log2(W);
datalines;
	1    10     5   0.25  -1.415   0.495  -1.577
    1    10    10   0.15  -1.926   0.382  -2.011
    1    10    15   0.18  -1.766   0.419  -1.876
    1    10    20   0.35  -0.981   0.599  -1.614
    1    10    25   0.48  -0.067   0.769  -0.796
    1    10    35   0.48  -0.067   0.769  -0.796
    1    15     5   0.22  -1.554   0.461  -1.686
    1    15    10   0.52   0.067   0.802  -0.467
    1    15    15   0.65   0.790   0.957   0.012
    1    15    20   0.58   0.708   0.905  -0.086
    1    15    25   0.85   2.169   1.209   0.748
    1    15    35   0.58   0.610   0.894  -0.224
    1    20     5   0.28  -1.353   0.520  -1.580
    1    20    10   0.42  -0.366   0.698  -1.040
    1    20    15   0.35  -0.981   0.599  -1.614
    1    20    20   0.52   0.067   0.802  -0.699
    1    20    25   0.45  -0.206   0.735  -0.673
    1    20    35   0.55   0.548   0.868  -0.221
    1    25     5   0.28  -1.353   0.520  -1.580
    1    25    10   0.42  -0.366   0.698  -1.040
    1    25    15   0.35  -0.981   0.599  -1.614
    1    25    20   0.52   0.067   0.802  -0.699
    1    25    25   0.45  -0.206   0.735  -0.673
    1    25    35   0.55   0.548   0.868  -0.221
    1    30     5   0.28  -1.353   0.520  -1.580
    1    30    10   0.42  -0.366   0.698  -1.040
    1    30    15   0.35  -0.981   0.599  -1.614
    1    30    20   0.52   0.067   0.802  -0.699
    1    30    25   0.45  -0.206   0.735  -0.673
    1    30    35   0.55   0.548   0.868  -0.221
    1    35     5   0.28  -1.353   0.520  -1.580
    1    35    10   0.42  -0.366   0.698  -1.040
    1    35    15   0.35  -0.981   0.599  -1.614
    1    35    20   0.52   0.067   0.802  -0.699
    1    35    25   0.45  -0.206   0.735  -0.673
    1    35    35   0.55   0.548   0.868  -0.221
    2    10     5   0.15  -1.926   0.382  -2.011
    2    10    10   0.08  -2.541   0.283  -2.586
    2    10    15   0.35  -0.738   0.620  -1.005
    2    10    20   0.35  -0.738   0.620  -1.005
    2    10    25   0.52  -0.006   0.794  -0.481
    2    10    35   0.62   0.822   0.936  -0.033
    2    15     5   0.25  -1.415   0.495  -1.577
    2    15    10   0.15  -1.926   0.382  -2.011
    2    15    15   0.18  -1.766   0.419  -1.876
    2    15    20   0.35  -0.981   0.599  -1.614
    2    15    25   0.48  -0.067   0.769  -0.796
    2    15    35   0.48  -0.067   0.769  -0.796
    2    20     5   0.28  -1.353   0.520  -1.580
    2    20    10   0.58   0.610   0.894  -0.224
    2    20    15   0.58   0.610   0.894  -0.224
    2    20    20   0.65   0.981   0.972  -0.259
    2    20    25   0.72   1.353   1.050   0.298
    2    20    35   0.82   2.030   1.175   0.656
    2    25     5   0.35  -0.981   0.599  -1.255
    2    25    10   0.52   0.166   0.813  -0.348
    2    25    15   0.55   0.470   0.859  -0.315
    2    25    20   0.52   0.067   0.802  -0.381
    2    25    25   0.62   0.822   0.936  -0.033
    2    25    35   0.75   1.757   1.108   0.451
    2    30     5   0.35  -0.981   0.599  -1.255
    2    30    10   0.52   0.166   0.813  -0.348
    2    30    15   0.55   0.470   0.859  -0.315
    2    30    20   0.52   0.067   0.802  -0.381
    2    30    25   0.62   0.822   0.936  -0.033
    2    30    35   0.75   1.757   1.108   0.451
    2    35     5   0.35  -0.981   0.599  -1.255
    2    35    10   0.52   0.166   0.813  -0.348
    2    35    15   0.55   0.470   0.859  -0.315
    2    35    20   0.52   0.067   0.802  -0.381
    2    35    25   0.62   0.822   0.936  -0.033
    2    35    35   0.75   1.757   1.108   0.451
    3    10     5   0.35  -0.981   0.599  -1.255
    3    10    10   0.52   0.166   0.813  -0.348
    3    10    15   0.55   0.470   0.859  -0.315
    3    10    20   0.52   0.067   0.802  -0.381
    3    10    25   0.62   0.822   0.936  -0.033
    3    10    35   0.75   1.757   1.108   0.451
    3    15     5   0.28  -1.353   0.520  -1.580
    3    15    10   0.58   0.610   0.894  -0.224
    3    15    15   0.58   0.610   0.894  -0.224
    3    15    20   0.65   0.981   0.972  -0.259
    3    15    25   0.72   1.353   1.050   0.298
    3    15    35   0.82   2.030   1.175   0.656
    3    20     5   0.28  -1.353   0.520  -1.580
    3    20    10   0.58   0.610   0.894  -0.224
    3    20    15   0.58   0.610   0.894  -0.224
    3    20    20   0.65   0.981   0.972  -0.259
    3    20    25   0.72   1.353   1.050   0.298
    3    20    35   0.82   2.030   1.175   0.656
    3    25     5   0.28  -1.353   0.520  -1.580
    3    25    10   0.58   0.610   0.894  -0.224
    3    25    15   0.58   0.610   0.894  -0.224
    3    25    20   0.65   0.981   0.972  -0.259
    3    25    25   0.72   1.353   1.050   0.298
    3    25    35   0.82   2.030   1.175   0.656
    3    30     5   0.28  -1.353   0.520  -1.580
    3    30    10   0.58   0.610   0.894  -0.224
    3    30    15   0.58   0.610   0.894  -0.224
    3    30    20   0.65   0.981   0.972  -0.259
    3    30    25   0.72   1.353   1.050   0.298
    3    30    35   0.82   2.030   1.175   0.656
    3    35     5   0.35  -0.981   0.599  -1.255
    3    35    10   0.52   0.166   0.813  -0.348
    3    35    15   0.55   0.470   0.859  -0.315
    3    35    20   0.52   0.067   0.802  -0.381
    3    35    25   0.62   0.822   0.936  -0.033
    3    35    35   0.75   1.757   1.108   0.451
    4    10     5   0.25  -1.757   0.463  -1.964
    4    10    10   0.35  -0.981   0.599  -1.614
    4    10    15   0.55   0.569   0.870  -0.196
    4    10    20   0.55   0.470   0.859  -0.315
    4    10    25   0.65   0.981   0.972   0.059
    4    10    35   0.72   1.255   1.040   0.307
    4    15     5   0.28  -1.353   0.520  -1.580
    4    15    10   0.38  -0.578   0.656  -1.230
    4    15    15   0.42  -0.366   0.698  -1.040
    4    15    20   0.65   0.981   0.972   0.101
    4    15    25   0.52   0.409   0.834  -0.330
    4    15    35   0.72   1.597   1.071   0.316
    4    20     5   0.62   0.769   0.930  -0.131
    4    20    10   0.65   0.981   0.972   0.059
    4    20    15   0.65   0.981   0.972   0.101
    4    20    20   0.85   2.169   1.209   0.748
    4    20    25   0.78   1.627   1.118   0.504
    4    20    35   0.95   2.944   1.345   1.097
    4    25     5   0.48   0.006   0.777  -0.483
    4    25    10   0.52   0.336   0.826  -0.411
    4    25    15   0.68   1.115   1.005   0.216
    4    25    20   0.78   1.554   1.110   0.491
    4    25    25   0.58   0.444   0.881  -0.130
    4    25    35   0.72   1.353   1.050   0.298
    4    30     5   0.55   0.206   0.836  -0.608
    4    30    10   0.62   0.578   0.915  -0.411
    4    30    15   0.82   1.766   1.152   0.595
    4    30    20   0.85   2.169   1.209   0.748
    4    30    25   0.85   2.169   1.209   0.748
    4    30    35   0.85   2.169   1.209   0.748
    4    35     5   0.18  -1.714   0.424  -1.821
    4    35    10   0.42  -0.366   0.698  -1.040
    4    35    15   0.45  -0.206   0.735  -0.905
    4    35    20   0.68   1.121   1.006   0.210
    4    35    25   0.68   1.121   1.006   0.210
    4    35    35   0.78   1.896   1.142   0.560
;
run;
title 'Phomopsis on strawberry (Nita et al.)';
ods html style=statistical;


*---Start by considering W (and T) as FACTORS, not continuous variables....;
proc glimmix  data=tw2    plots=studentpanel  ;
	title2 'split plot (T as whole, W as sub), CLL transformation';
	title3 '(all variables as FACTORS)';
	class R T W ;
	model cll = T|W  / ddfm=kr;
	random R R*T ;		*<--random effects for block and whole-plot error;
	lsmeans T*W / slice=W plots=mean(join cl sliceby=T) cl ;
	*^--Note: procedure gives equal spacing of the Ts in the graph,
		even though they are not equally spaced.;
	lsmeans W / lines plots=mean(join clband) cl ;
	lsmeans T / lines plots=mean(join clband) cl ;
	*^--Mean separations are very unenlightened for a continuous factor;
	ods output lsmeans=lsmeans;		*<--get a file with the means;
run;
proc print data=lsmeans;run;

*---Look at means plotted versus W where the actual values are preserved....;
proc sgplot data=lsmeans(where=(Effect eq "T*W"));
scatter x=w y=estimate / yerrorupper=Upper yerrorlower=Lower group=T;
series x=w y=estimate / group=T;
run;

proc sgplot data=lsmeans(where=(Effect eq "W"));
scatter x=w y=estimate / yerrorupper=Upper yerrorlower=Lower ;
series x=w y=estimate ;
run;

*---From the analysis, only W is significant (for affecting the CLL of disease).
	Later, we pretend that T and T*W are also significant in order to show
	the methodology. For now, we work just with W.... We can remover
	T and T*W because they are not significant;

*---So, is there a linear straight-line relation between CLL and W? In classical
	ANOVA, a common practice is to use orthogonal contrasts to test for
	straight-line, quadratic, cubic, quartic effects. This can be
	cumbersome, especially with multiple factors and interactions. 
	Here we take a different approach that allows us to obtain the
	coefficients for W, W^2, etc.;
*---Start by treating W as a continuous variable (take it out of the 
	CLASS statement). One _cannot_ use LSMEANS (or SLICE) statements
	with continuous variables (these are only for factors (CLASS
	variables). However, we _can_ look at predictions of Y (CLL^)
	at each W. To do so, we need to use the OUTPUT statement as
	shown below....;
proc glimmix  data=tw2    plots=studentpanel  ;
	title2 'split plot (T as whole, W as sub), CLL transformation';
	title3 '(W as a continuous variable, no other explanatory variables)';
	class R T  ;					*<--no W in CLASS;
	model cll = W   / ddfm=kr s;	*<--GET THE ESTIMATED PARAMETERS;
	random R R*T ;					*<--random effects for block and whole-plot error;
	*^--One cannot use LSMEANS (or SLICE) for continuous variables;
	output out=tw2preds pred(noblup)=pred student(noblup)=student;
	*^--put the predictions of each observation and the studentized
		residuals in a data file for later plotting.;
run;
*proc print data=tw2preds;run;
proc sort data=tw2preds out=tw2predss;	*<--sorting will help for later plots;
by  W T;
proc sgplot data=tw2predss;
scatter x=w y=cll /  group=T;
series x=w y=pred ;
run;


*---There is some graphic evidence that there could be some significant curvature
	to the CLL:W relationship. We can easily test this by including W as _both_
	a continuous and factor variable in the model. Note that Wc is the same
	as W. We put Wc in the CLASS statement. The model statement has W and Wc,
	in that order.;
*---Very importantly, one uses so-called Type 1 (I) tests of hypotheses, which
	means that terms are tested in order. W is tested assuming that nothing
	else is in the model (except the intercept). Then Wc (as a factor) is
	tested assuming that W (as a continuous variable) is already in the model.
	If there is curvature, then Wc will be significant. Use HTYPE=1 option.;
proc glimmix  data=tw2    plots=studentpanel  ;
	title2 'split plot (T as whole, W as sub), CLL transformation';
	title3 '(W as a continuous variable, followed by Wc as FACTOR)';
	title4 '(With HTYPE=1 testing, Wc effect indicates extent of nonlinearity)';
	class R T  Wc;							*<--no W in CLASS, but Wc included;
	model cll = W  Wc / ddfm=kr s HTYPE=1;	*<--need W and Wc in that order;
	random R R*T ;							*<--random effects for block and whole-plot error;
	output out=tw2preds pred(noblup)=pred student(noblup)=student;
	*^--put the predictions of each observation and the studentized
		residuals in a data file for later plotting.;
run;

*---There _is_ evidence of curvature, based on type 1 test of Wc. Note: a type 3
	test will blow up (overparameterized). One possibility now is to consider
	a linear and quadratic term, to get the predictions to bend towards the
	right a bit.;
proc glimmix  data=tw2    plots=studentpanel  ;
	title2 'split plot (T as whole, W as sub), CLL transformation';
	title3 '(W and W**W as continuous variables, not other variables)';
	class R T  ;						*<--no W in CLASS;
	model cll = W W*W  / ddfm=kr s;		*<--put in W and W*W (continuous variables);
	random R R*T ;						*<--random effects for block and whole-plot error;
	output out=tw2preds pred(noblup)=pred student(noblup)=student;
run;
*proc print data=tw2preds;run;
proc sort data=tw2preds out=tw2predss;
by  W T;
proc sgplot data=tw2predss;
scatter x=w y=cll /  group=T;
series x=w y=pred ;
run;

*---One could continue this, with W W*W and Wc (CLASS) in the model, to see if one
	can stop with linear and quadratic terms. However, it may make more sense
	to capture the curvature by transforming W, say to sqrt(W) or log(W). We
	try this here. ;
proc glimmix  data=tw2    plots=studentpanel  ;
	title2 'split plot (T as whole, W as sub), CLL transformation';
	title3 '(log(W) [lW] as a continuous variable, no other variables)';
	title4 '(transformation of x captures nonlinearity without using W*W)';
	class R T  ;						*<--no W in CLASS;
	model cll = lW  / ddfm=kr s;		*<--try a transformation of W;
	random R R*T ;						*<--random effects for block and whole-plot error;
	output out=tw2preds pred(noblup)=pred student(noblup)=student;
run;
*proc print data=tw2preds;run;
proc sort data=tw2preds out=tw2predss;
by  W T;
proc sgplot data=tw2predss;
scatter x=w y=cll /  group=T;
series x=w y=pred ;
run;
proc sgplot data=tw2predss;
scatter x=lw y=cll /  group=T;
series x=lw y=pred ;
run;


*---Now we can see if use of logW gives an adequate fit to the data.
	We, once again, test for curvature by including Wc in the model
	as a FACTOR, and use HTYPE=1 for F test.;
proc glimmix  data=tw2    plots=studentpanel  ;
	title2 'split plot (T as whole, W as sub), CLL transformation';
	title3 '(log(W) [lW] as a continuous variable, followed by Wc as FACTOR)';
	title4 '(With HTYPE=1 testing, Wc effect indicates extent of nonlinearity)';
	class R T  Wc ;								*<--no W in CLASS, but Wc in CLASS;
	model cll = lW Wc / ddfm=kr s HTYPE=1;		*<--try a transformation of W, and Wc factor;
	random R R*T ;						*<--random effects for block and whole-plot error;
	output out=tw2preds pred(noblup)=pred student(noblup)=student;
run;


*---Since Wc is not significant, we stop with lW as the continuous variable.
	But, let's go back and explore the T effects a little. We fit the lW model
	again, and now see how the predictions of CLL correspond to different Ts.;
proc glimmix  data=tw2    plots=studentpanel  ;
	title2 'split plot (T as whole, W as sub), CLL transformation';
	title3 '(log(W) as continuous variable, no other variables)';
	class R T  ;						*<--no W in CLASS;
	model cll = lW  / ddfm=kr s;		*<--try a transformation of W;
	random R R*T ;						*<--random effects for block and whole-plot error;
	output out=tw2preds pred(noblup)=pred student(noblup)=student;
run;
*proc print data=tw2preds;run;
proc sort data=tw2preds out=tw2predss;
by  W T;
proc sgplot data=tw2predss;
scatter x=w y=cll /  group=T;
series x=w y=pred ;
run;
proc sgpanel data=tw2predss;		*<--get separate graphs for each T in a panel;
panelby T;
scatter x=w y=cll ;
series x=w y=pred ;
run;

*---Now, we sort-of go back to the beginning, using a model with lW, T, and lW*T.
	The next run still shows that T and the interaction are not significant, but
	let's pretend that they are. As you can see, there is evidence in the panel
	graph below that the fit is better when T is considered. ;
*---Note what it means if T and lW*W are significant:
		(1) the intercept of the CLL:lW line depends on T.
		(2) the slope of the CLL:lW line depends on T.;
proc glimmix  data=tw2    plots=studentpanel  ;
	title2 'split plot (T as whole, W as sub), CLL transformation';
	title3 '(log(W) [lW] as continuous variable, T (factor), and log(W)*T)';
	title4 'see Solution table for parameter estimates, need to add terms for each T';
	class R T  Wc;							*<--no W in CLASS;
	model cll = lW T lW*T  / ddfm=kr s;		*<--using lW instead of W;
	random R R*T ;							*<--random effects for block and whole-plot error;
	output out=tw2preds pred(noblup)=pred student(noblup)=student;
run;
*proc print data=tw2preds;run;
proc sort data=tw2preds out=tw2predss;
by  W T;
proc sgplot data=tw2predss;
scatter x=w y=cll /  group=T;
series x=w y=pred / group=T;
run;
proc sgpanel data=tw2predss;		*<--get separate graphs for each T in a panel;
panelby T;
scatter x=w y=cll ;
series x=w y=pred ;
run;

*---If there is an interaction of lW and T, this means that the slope of 
	CLL:lW depends on the T. With a T effect, this means that the intercept 
	of CLL:lW depends on T. One can get all of this from the Solution table
	in the above run. Use of multiple ESTIMATE statements (which we have not
	covered) could be use to formally get the needed slopes and intercepts, and
	the corresponding SEs.;
*---Example: to get the intercept of CLL:lW line for T=10, add the overall 
	intercept to the parameter for T=10. 
	To get the slope for the CLL:lW line for T=10, add the parameter for 
	lW in the Solution table to the parameter for T=10 in lW*T part of the
	Solution table.;
*---One way to get slopes and intercepts easier is to re-fit the above 
	model, but with two changes:
	(1) we add the NOINT option to the MODEL
	statement. This takes out the overall intercept. The consequence of this
	is that the Solution table for T directly gives the intercepts for CLL:lW.
	(2) take out the lW term in the mdoel, (lW is still there as part of the
	interaction, just not as a main effect). Thus, the Solution table for lW*T
	directly gives the slopes for CLL:lW.;
*---Important note: the fit must be the same as immediately above. The different
	here is that the overparameterization is eliminated;
proc glimmix  data=tw2    plots=studentpanel  ;
	title2 'split plot (T as whole, W as sub), CLL transformation';
	title3 '(W as a continuous variable)';
	class R T  Wc;									
	model cll = T lW*T  / ddfm=kr s NOINT;		*<--using lW instead of W;
	random R R*T ;							
	output out=tw2preds pred(noblup)=pred student(noblup)=student;
run;
*proc print data=tw2preds;run;
proc sort data=tw2preds out=tw2predss;
by  W T;
proc sgplot data=tw2predss;
scatter x=w y=cll /  group=T;
series x=w y=pred / group=T;
run;
proc sgpanel data=tw2predss;		*<--get separate graphs for each T in a panel;
panelby T;
scatter x=w y=cll ;
series x=w y=pred ;
run;



